import{_ as e,a as n,o as a,F as s,s as t,e as r,w as o,b as i,t as l,v as c,H as u,q as d,f as h}from"./index-Dj1dnKzO.js";import{u as m}from"./experiment-DW4ZkdFG.js";const p={class:"lg:w-48 lg:h-auto lg:px-4 lg:transition-none px-6 w-0 h-0 transition-all overflow-hidden"},v=e({__name:"SiderNav",setup(e){const d=[{key:"index",to:"index",icon:"home"},{key:"hardware",to:"hardware",icon:"config"},{key:"requirements",to:"requirements",icon:"help"}];return(e,h)=>{const m=c,v=u("router-link");return a(),n("div",null,[(a(),n(s,null,t(d,(n=>r(v,{key:n.key,to:n.to,"active-class":"active-router"},{default:o((()=>[i("span",p,l(e.$t(`experiment.env.navs.${n.key}`)),1),r(m,{icon:n.icon,class:"w-4 h-4 lg:w-0 lg:h-0 transition-all absolute left-4"},null,8,["icon"])])),_:2},1032,["to"]))),64))])}}},[["__scopeId","data-v-2a435598"]]),f={class:"w-full rounded-lg mr-6"},x={__name:"EnvironmentPage",setup(e){const s=m();return(e,t)=>{const o=u("RouterView");return a(),n("div",{class:d(["w-full h-full flex p-6 bg-higher",h(s).experiment.description?"min-h-[calc(100vh-195px)]":"min-h-[calc(100vh-163px)]"])},[r(v,{class:"shrink-0 mr-6"}),i("div",f,[r(o)])],2)}}};export{x as default};
