import{u as e}from"./experiment-DW4ZkdFG.js";import{u as t,c as a,a as l,b as s,g as n,d as r,t as i,o as p}from"./index-Dj1dnKzO.js";import{g as u,E as o}from"./parser-BfU2RQDE.js";const m={class:"w-full border p-6 rounded-lg bg-default"},d={class:"w-full text-xl font-semibold pb-4 border-b"},v={__name:"EnvIndex",setup(v){const{experiment:x}=e(),g=t(),y=a((()=>u(x,g)));return(e,t)=>(p(),l("div",m,[s("h1",d,i(e.$t("experiment.env.title.overview")),1),y.value.experiment?(p(),n(o,{key:0,title:e.$t("experiment.env.groups.experiment"),data:y.value.experiment},null,8,["title","data"])):r("",!0),y.value.system?(p(),n(o,{key:1,title:e.$t("experiment.env.groups.system"),data:y.value.system},null,8,["title","data"])):r("",!0),y.value.python?(p(),n(o,{key:2,title:e.$t("experiment.env.groups.python"),data:y.value.python},null,8,["title","data"])):r("",!0),y.value.git?(p(),n(o,{key:3,title:e.$t("experiment.env.groups.git"),data:y.value.git},null,8,["title","data"])):r("",!0)]))}};export{v as default};
