import{u as e}from"./experiment-DW4ZkdFG.js";import{a,b as l,E as t}from"./parser-BfU2RQDE.js";import{a as u,o as n,b as r,e as p,t as v,F as s,s as d,c as i,g as m,d as o}from"./index-Dj1dnKzO.js";const y={class:"w-full py-5 flex-col space-y-5"},c={class:"flex items-center gap-2 font-semibold"},f={class:"text-dimmer w-44 shrink-0"},g={class:"max-w-96 w-full break-words whitespace-wrap shrink"},x={class:"shrink-0 pl-8"},k={__name:"NvidiaGpu",props:{data:{type:{driver:String,cuda:String,cores:Number,memory:Array,type:Array},default:()=>({})},type:{type:String,default:"gpu"}},setup:e=>(l,t)=>(n(),u("div",y,[r("h1",c,v(l.$t(`experiment.env.groups.${e.type}`)),1),p(a,{"env-key":"gpu_driver","env-value":e.data.driver},null,8,["env-value"]),p(a,{"env-key":"cuda","env-value":e.data.cuda},null,8,["env-value"]),p(a,{"env-key":"gpu_cores","env-value":e.data.cores},null,8,["env-value"]),(n(!0),u(s,null,d(e.data.memory,((a,l)=>{var t;return n(),u("div",{class:"w-full flex",key:l},[r("span",f,"GPU"+v(l),1),r("span",g,v(null==(t=e.data.type)?void 0:t[l]),1),r("span",x,v(a)+" GB",1)])})),128))]))},w={class:"w-full py-5 flex-col space-y-5"},b={class:"flex items-center gap-2 font-semibold"},h={__name:"AppleChip",props:{data:{type:{type:String,cpu:String,gpu:String,memory:String},default:{}}},setup:e=>(l,t)=>(n(),u("div",w,[r("h1",b,v(l.$t("experiment.env.groups.apple")),1),p(a,{"env-key":"brand","env-value":e.data.type},null,8,["env-value"]),p(a,{"env-key":"cpu","env-value":e.data.cpu},null,8,["env-value"]),p(a,{"env-key":"memory","env-value":e.data.memory+"GB"},null,8,["env-value"])]))},_={key:0,class:"w-full border p-6 rounded-lg bg-default"},S={class:"w-full text-xl font-semibold pb-4 border-b"},$={key:1},j={class:"text-center pt-5"},G={__name:"EnvHardware",setup(a){const{experiment:p}=e(),s=i((()=>l(p))),d=i((()=>{var e;return null==(e=s.value)?void 0:e.apple})),y=e=>!!e&&(null==e?void 0:e.filter((e=>e.value)).length)>0,c=i((()=>y(s.value.cpu))),f=i((()=>y(s.value.memory))),g=i((()=>s.value.apple||c.value||f.value||s.value.gpu));return(e,a)=>g.value?(n(),u("div",_,[r("h1",S,v(e.$t("experiment.env.title.hardware")),1),d.value?(n(),m(h,{key:0,data:s.value.apple},null,8,["data"])):o("",!0),c.value&&!d.value?(n(),m(t,{key:1,title:e.$t("experiment.env.groups.cpu"),data:s.value.cpu},null,8,["title","data"])):o("",!0),f.value&&!d.value?(n(),m(t,{key:2,data:s.value.memory},null,8,["data"])):o("",!0),s.value.nvidia?(n(),m(k,{key:3,data:s.value.nvidia,type:"nvidia"},null,8,["data"])):s.value.gpu?(n(),m(k,{key:4,data:s.value.gpu,type:"gpu"},null,8,["data"])):o("",!0)])):(n(),u("div",$,[r("p",j,v(e.$t("experiment.env.empty.hardware")),1)]))}};export{G as default};
